pub enum Direction {
Horizontal,
Vertical,
}Expand description
The animation direction (and layout axis) of a LinearSpinner.
Examples
use tui_spinner::{LinearSpinner, Direction};
let horizontal = LinearSpinner::new(0).direction(Direction::Horizontal);
let vertical = LinearSpinner::new(0).direction(Direction::Vertical);Variants
Horizontal
A window of lit symbols scrolls left-to-right across a single row.
The widget occupies 1 row of height and total_slots columns of width.
Vertical
A single lit symbol bounces up and down a single column.
The widget occupies 1 column of width and total_slots rows of height.
When the area is taller than total_slots the symbols are pinned to the
bottom so they align with the last log line in a side-column layout.